@@ -47,6 +47,7 @@
 #include "hw_ostc3.h"
 #include "cressi_edy.h"
 #include "cressi_leonardo.h"
+#include "cressi_goa.h"
 #include "zeagle_n2ition3.h"
 #include "atomics_cobalt.h"
 #include "shearwater_petrel.h"
@@ -181,6 +182,9 @@ dc_device_open (dc_device_t **out, dc_context_t *context, dc_descriptor_t *descr
 	case DC_FAMILY_CRESSI_LEONARDO:
 		rc = cressi_leonardo_device_open (&device, context, iostream);
 		break;
+	case DC_FAMILY_CRESSI_GOA:
+		rc = cressi_goa_device_open (&device, context, iostream);
+		break;
 	case DC_FAMILY_ZEAGLE_N2ITION3:
 		rc = zeagle_n2ition3_device_open (&device, context, iostream);
 		break;
