@@ -50,6 +50,7 @@
 #define CHROMIS           0x24
 #define MANTIS2           0x26
 #define G2                0x32
+#define G2HUD             0x42
 
 #define UNSUPPORTED 0xFFFFFFFF
 
@@ -529,7 +530,7 @@ uwatec_smart_parser_cache (uwatec_smart_parser_t *parser)
 					parser->model == ALADIN2G || parser->model == MERIDIAN ||
 					parser->model == CHROMIS || parser->model == MANTIS2 ||
 					parser->model == G2 || parser->model == ALADINSPORTMATRIX ||
-					parser->model == ALADINSQUARE) {
+					parser->model == ALADINSQUARE || parser->model == G2HUD) {
 					unsigned int offset = header->tankpressure + 2 * i;
 					endpressure   = array_uint16_le(data + offset);
 					beginpressure = array_uint16_le(data + offset + 2 * header->ngases);
@@ -620,6 +621,7 @@ uwatec_smart_parser_create (dc_parser_t **out, dc_context_t *context, unsigned i
 		parser->nevents[2] = C_ARRAY_SIZE (uwatec_smart_galileo_events_2);
 		break;
 	case G2:
+	case G2HUD:
 	case ALADINSPORTMATRIX:
 		parser->headersize = 84;
 		parser->header = &uwatec_smart_trimix_header;
@@ -963,7 +965,7 @@ uwatec_smart_parse (uwatec_smart_parser_t *parser, dc_sample_callback_t callback
 			parser->model == ALADIN2G || parser->model == MERIDIAN ||
 			parser->model == CHROMIS || parser->model == MANTIS2 ||
 			parser->model == G2 || parser->model == ALADINSPORTMATRIX ||
-			parser->model == ALADINSQUARE) {
+			parser->model == ALADINSQUARE || parser->model == G2HUD) {
 			// Uwatec Galileo
 			id = uwatec_galileo_identify (data[offset]);
 		} else {
